/*
 * Copyright (C) 2022-2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include <cstdint>

using TaskCountType = uint64_t;
using TagAddressType = uint64_t;
